==> HostCMS.Free_6.7.tar.gz: modules/template/i18n/ru.php <==
<?php
/**
 * Templates.
 *
 * @package HostCMS
 * @subpackage Template
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Макеты сайта',
	'menu' => 'Макеты сайта',
	'title' => 'Макеты сайта',
	'menu1' => 'Макет',
	'menu_add' => 'Добавить',
	'title_add' => 'Добавление макета',
	'title_edit' => 'Редактирование макета "%s"',
	'tab_1' => 'Макет',
	'tab_2' => 'CSS/LESS',
	'tab_3' => 'Javascript',
	'tab_4' => 'Манифест',
	'breadCrumb' => 'Макет "%s"',
	'id' => 'Идентификатор',
	'name' => '<acronym title="Название макета">Название макета</acronym>',
	'template_dir_id' => '<acronym title="Раздел макетов, которой принадлежит макет">Раздел макетов</acronym>',
	'sorting' => '<acronym title="Поле, по которому производится сортировка">Сортировка</acronym>',
	'site_id' => 'Идентификатор сайта',
	'template_id' => 'Родительский макет',
	'template' => '<acronym title="Код макета">Макет</acronym>',
	'css' => '<acronym title="Описание стилей">CSS/LESS</acronym>',
	'less' => '<acronym title="Apply LESS">LESS</acronym>',
	'js' => '<acronym title="Код js-скриптов">Javascript</acronym>',
	'manifest' => '<acronym title="Код манифеста для LESS">Манифест</acronym>',
	'copy_success' => 'Макет успешно скопирован!',
	'copy_error' => 'Ошибка! Макет не скопирован!',
	'markDeleted_success' => 'Макет успешно удален!',
	'markDeleted_error' => 'Ошибка! Макет не удален!',
	'edit_success' => 'Информация о макете добавлена!',
	'edit_error' => 'Ошибка! Информация о макете не добавлена!',
	'apply_success' => 'Данные успешно обновлены!',
	'apply_error' => 'Ошибка! Данные для действия не изменены.',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'error_less_off' => 'LESS выключен для данного макета. Отредактируйте макет и включите его.',
	'error_access_forbidden' => 'Доступ к редактированию макета запрещен.',
);

==> HostCMS.Free_7.0.tar.gz: modules/template/i18n/ru.php <==
<?php
/**
 * Templates.
 *
 * @package HostCMS
 * @subpackage Template
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2019 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Макеты сайта',
	'menu' => 'Макеты сайта',
	'title' => 'Макеты сайта',
	'menu1' => 'Макет',
	'menu_add' => 'Добавить',
	'title_add' => 'Добавление макета',
	'title_edit' => 'Редактирование макета "%s"',
	'tab_1' => 'Макет',
	'tab_2' => 'CSS/LESS/SCSS',
	'tab_3' => 'Javascript',
	'tab_4' => 'Манифест',
	'tab_5' => 'Язык',
	'breadCrumb' => 'Макет "%s"',
	'id' => 'Идентификатор',
	'name' => 'Название макета',
	'template_dir_id' => 'Раздел макетов',
	'sorting' => 'Сортировка',
	'site_id' => 'Идентификатор сайта',
	'template_id' => 'Родительский макет',
	'template' => '<acronym title="Код макета">Макет</acronym>',
	'css' => '<acronym title="Описание стилей">CSS/LESS/SCSS</acronym>',
	'less' => '<acronym title="Используется LESS">LESS</acronym>',
	'js' => '<acronym title="Код js-скриптов">Javascript</acronym>',
	'manifest' => '<acronym title="Код манифеста для LESS">Манифест</acronym>',
	'copy_success' => 'Макет успешно скопирован!',
	'copy_error' => 'Ошибка! Макет не скопирован!',
	'markDeleted_success' => 'Макет успешно удален!',
	'markDeleted_error' => 'Ошибка! Макет не удален!',
	'edit_success' => 'Информация о макете добавлена!',
	'edit_error' => 'Ошибка! Информация о макете не добавлена!',
	'apply_success' => 'Данные успешно обновлены!',
	'apply_error' => 'Ошибка! Данные для действия не изменены.',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'error_less_off' => 'LESS выключен для данного макета. Отредактируйте макет и включите его.',
	'error_access_forbidden' => 'Доступ к редактированию макета запрещен.',
	'language' => '%s.php',
	'type' => 'Тип',
);
